@@ -171,7 +171,7 @@ def run_container_validation_tests_filesystem(container, snapshot_status=None):
                         newcases.append(new_testcase)
             testset['cases'] = newcases
         # print(json.dumps(test_json_data, indent=2))
-        resultset = run_json_validation_tests(test_json_data, container, True, snapshot_status)
+        resultset = run_json_validation_tests(test_json_data, container, False, snapshot_status)
         if resultset:
             snapshot = test_json_data['snapshot'] if 'snapshot' in test_json_data else ''
             dump_output_results(resultset, container, test_file, snapshot, True)
@@ -185,6 +185,24 @@ def run_container_validation_tests_filesystem(container, snapshot_status=None):
             finalresult = False
     return finalresult
 
+def _get_snapshot_type_map(container):
+    dbname = config_value(DATABASE, DBNAME)
+    collection = config_value(DATABASE, collectiontypes[SNAPSHOT])
+    qry = {'container': container}
+    docs = get_documents(collection, dbname=dbname, query=qry)
+    mappings = {}
+    if docs and len(docs):
+        for doc in docs:
+            given_data = doc['json']
+            if given_data:
+                snapshots = given_data.get("snapshots", [])
+                for snapshot in snapshots:
+                    given_type = snapshot.get("type","")
+                    if given_type == "aws":
+                        nodes = snapshot.get("nodes",[])
+                        for node in nodes:
+                            mappings[node['snapshotId']] = node['type']
+    return mappings
 
 def run_container_validation_tests_database(container, snapshot_status=None):
     """ Get the test files from the database"""
@@ -215,6 +233,7 @@ def run_container_validation_tests_database(container, snapshot_status=None):
     # For mastertest files
     collection = config_value(DATABASE, collectiontypes[MASTERTEST])
     docs = get_documents(collection, dbname=dbname, sort=sort, query=qry)
+    # snapshots_details_map = _get_snapshot_type_map(container)
     if docs and len(docs):
         logger.info('Number of mastertest Documents: %s', len(docs))
         for doc in docs:
@@ -233,15 +252,17 @@ def run_container_validation_tests_database(container, snapshot_status=None):
                     for testcase in testcases:
                         rule_str = get_field_value_with_default(testcase, 'rule', '')
                         ms_ids = re.findall(r'\{(.*)\}', rule_str)
+                        # detail_method = get_field_value(testcase, 'detailMethod')
                         for ms_id in ms_ids:
                             for s_id in mastersnapshots[ms_id]:
                                 # new_rule_str = re.sub('{%s}' % ms_id, '{%s}' % s_id, rule_str)
+                                # if not detail_method or detail_method == snapshots_details_map[s_id]:
                                 new_rule_str = rule_str.replace('{%s}' % ms_id, '{%s}' % s_id)
                                 new_testcase = {'rule': new_rule_str, 'testId': testcase['masterTestId']}
                                 newcases.append(new_testcase)
                     testset['cases'] = newcases
                 # print(json.dumps(test_json_data, indent=2))
-                resultset = run_json_validation_tests(test_json_data, container, True, snapshot_status)
+                resultset = run_json_validation_tests(test_json_data, container, False, snapshot_status)
                 if resultset:
                     snapshot = doc['json']['snapshot'] if 'snapshot' in doc['json'] else ''
                     test_file = doc['name'] if 'name' in doc else ''
