@@ -8,7 +8,7 @@ import os
 from pymongo import MongoClient
 from pymongo.errors import ServerSelectionTimeoutError
 from processor.helper.config.config_utils import framework_dir,\
-    get_config_data, framework_config, TESTS, NODB, config_value
+    get_config_data, framework_config, TESTS, DBVALUES, NONE, config_value
 
 
 FWLOGGER = None
@@ -22,11 +22,9 @@ dbhandler = None
 class MongoDBHandler(logging.Handler):
     """Customized logging handler that puts logs to the database, pymongo required
     """
-    def __init__(self, dburl, dbname):
-        global DBLOGGER
+    def __init__(self, dburl, dbname, collection='logs'):
         logging.Handler.__init__(self)
         try:
-            # dbconnection = MongoClient(port=27017, serverSelectionTimeoutMS=3000)
             dbconnection =  MongoClient(host=dburl, serverSelectionTimeoutMS=3000)
             _ = dbconnection.list_database_names()
             if dbname:
@@ -34,34 +32,30 @@ class MongoDBHandler(logging.Handler):
             else:
                 db = dbconnection['test']
             # collection = 'logs_%s' % datetime.datetime.now().strftime('%Y%M%d%H%M%S')
+            self.coll_name = collection
+            self.log_name = ''
             if db:
                 self.db = db
                 self.set_log_collection()
             else:
                 self.collection = None
-                self.coll_name = ''
-                # coll = db[collection]
-                # self.db = db
-                # self.collection = coll
-                # # DBLOGGER = '%s:%s' % (dbname, collection)
-                # DBLOGGER = collection
         except ServerSelectionTimeoutError as ex:
             self.collection = None
 
     def set_log_collection(self):
         global DBLOGGER
-        coll_name = 'logs_%s' % datetime.datetime.now().strftime('%Y%m%d%H%M%S')
-        coll = self.db[coll_name]
+        log_name = 'logs_%s' % datetime.datetime.now().strftime('%Y%m%d%H%M%S')
+        coll = self.db[self.coll_name]
         self.collection = coll
-        DBLOGGER = coll_name
-        self.coll_name = coll_name
+        DBLOGGER = log_name
+        self.log_name = log_name
+        self.collection.insert({'name': log_name, 'logs': []}, check_keys=False)
 
     def get_log_collection(self):
-        return self.coll_name
+        return self.log_name
 
     def reset_log_collection(self):
-        self.collection = None
-        self.coll_name = ''
+        self.log_name = ''
 
     def emit(self, record):
         """Add record to the database"""
@@ -77,14 +71,15 @@ class MongoDBHandler(logging.Handler):
         }
 
         try:
-            if self.collection:
-                self.collection.insert(db_record, check_keys=False)
+            if self.collection and self.log_name:
+                # self.collection.insert(db_record, check_keys=False)
+                self.collection.update({'name': self.log_name}, {'$push': {'logs': db_record}})
         except Exception as e:
             print('CRITICAL Logger DB ERROR: Logging to database not possible!')
 
 
 
-def logging_fw(fwconfigfile):
+def logging_fw(fwconfigfile, dbargs):
     """Framework file logging"""
     global FWLOGFILENAME, dbhandler
     fwlogfile = '%Y%m%d-%H%M%S'
@@ -124,11 +119,11 @@ def logging_fw(fwconfigfile):
         backupCount=log_config['backups']
     )
     handler.setFormatter(logging.Formatter(logformat))
-    handler.setLevel(log_config['level'])
+    # handler.setLevel(log_config['level'])
+    handler.setLevel(loglevel)
     logger.addHandler(handler)
     unittest = os.getenv('UNITTEST', "false")
-    nodb = config_value(TESTS, NODB, False)
-    if log_config['db'] and unittest != "true" and not nodb:
+    if log_config['db'] and unittest != "true" and dbargs:
         dblogformat = '%(asctime)s-%(message)s'
         dbhandler = MongoDBHandler(log_config['dburl'], log_config['db'])
         dbhandler.setFormatter(logging.Formatter(dblogformat))
@@ -137,12 +132,21 @@ def logging_fw(fwconfigfile):
     return logger
 
 
+def init_logger(dbargs, fw_cfg=None):
+    """Get the logger for the framework."""
+    global FWLOGGER
+    if FWLOGGER:
+        return FWLOGGER
+    FWLOGGER = logging_fw(fw_cfg, dbargs)
+    return FWLOGGER
+
+
 def getlogger(fw_cfg=None):
     """Get the logger for the framework."""
     global FWLOGGER
     if FWLOGGER:
         return FWLOGGER
-    FWLOGGER = logging_fw(fw_cfg)
+    FWLOGGER = logging_fw(fw_cfg, DBVALUES.index(NONE))
     return FWLOGGER
 
 def get_logdir(fw_cfg):
